// Copyright (C) 2023 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:wyatt_authentication_bloc/src/core/enums/authentication_status.dart';
import 'package:wyatt_authentication_bloc/src/domain/entities/auth_session.dart';
import 'package:wyatt_authentication_bloc/src/features/authentication/cubit/authentication_cubit.dart';

/// {@template authentication_builder}
/// A widget that builds itself based on the current authentication state.
/// {@endtemplate}
class AuthenticationBuilder<Data> extends StatelessWidget {
  /// {@macro authentication_builder}
  const AuthenticationBuilder({
    required this.authenticated,
    required this.unauthenticated,
    required this.unknown,
    super.key,
  });

  /// Widget to show when the user is authenticated.
  final Widget Function(
    BuildContext context,
    AuthenticationSession<Data> session,
  ) authenticated;

  /// Widget to show when the user is unauthenticated.
  final Widget Function(BuildContext context) unauthenticated;

  /// Widget to show when the authentication status is unknown.
  final Widget Function(BuildContext context) unknown;

  @override
  Widget build(BuildContext context) =>
      BlocBuilder<AuthenticationCubit<Data>, AuthenticationState<Data>>(
        builder: (context, state) {
          if (state.status == AuthenticationStatus.authenticated) {
            if (state.session != null) {
              return authenticated(context, state.session!);
            } else {
              return unauthenticated(context);
            }
          } else if (state.status == AuthenticationStatus.unauthenticated) {
            return unauthenticated(context);
          } else {
            return unknown(context);
          }
        },
      );
}
