// Copyright (C) 2023 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:flutter/widgets.dart';
import 'package:wyatt_component_copy_with_extension/wyatt_component_copy_with_extension.dart';
import 'package:wyatt_ui_components/wyatt_ui_components.dart';

part 'portfolio_card_component.g.dart';

@ComponentProxyExtension()
abstract class PortfolioCardComponent extends CardComponent
    with CopyWithMixin<$PortfolioCardComponentCWProxy> {
  const PortfolioCardComponent({
    this.showAssetsOnTop,
    this.keywords,
    this.keywordsBackgroundColors,
    this.description,
    this.logo,
    this.projectName,
    this.subtitle,
    this.ctas,
    this.assets,
    super.radius,
    super.padding,
    super.borderColors,
    super.backgroundColors,
    super.stroke,
    super.minSize,
    super.maxSize,
    super.shadow,
    super.titleStyle,
    super.subtitleStyle,
    super.bodyStyle,
    super.background,
    super.key,
  });

  /// Keywords of the portfolio
  final List<TextWrapper>? keywords;

  /// Background colors for the keywords badges
  final MultiColor? keywordsBackgroundColors;

  /// Assets to display
  final List<Widget>? assets;

  /// Whether to show the assets on top or on bottom
  /// of the card
  final bool? showAssetsOnTop;

  /// Logo of the portfolio
  final Widget? logo;

  /// Description of the portfolio
  final TextWrapper? description;

  /// Name of the portfolio
  final TextWrapper? projectName;

  /// Subtitle of the portfolio
  final TextWrapper? subtitle;

  /// Call to actions of the portfolio
  final List<Widget>? ctas;
}
